declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    title: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                    priority: import("zod").ZodOptional<import("zod").ZodEnum<{
                        high: "high";
                        medium: "medium";
                        low: "low";
                        none: "none";
                    }>>;
                    parent_id: import("zod").ZodOptional<import("zod").ZodString>;
                    type: import("zod").ZodEnum<{
                        epic: "epic";
                        feature: "feature";
                        enhancement: "enhancement";
                        bug: "bug";
                        task: "task";
                    }>;
                    status: import("zod").ZodOptional<import("zod").ZodEnum<{
                        open: "open";
                        in_progress: "in_progress";
                        started: "started";
                        done: "done";
                        completed: "completed";
                        closed: "closed";
                        cancelled: "cancelled";
                    }>>;
                    created_id: import("zod").ZodString;
                    assigned_id: import("zod").ZodOptional<import("zod").ZodString>;
                    creator: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    assignee: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    project: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>;
                    tag_ids: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            title: string;
            type: string;
            created_id: string;
            priority: string;
            status?: undefined;
            older_than?: undefined;
            limit?: undefined;
            body?: undefined;
            user_id?: undefined;
            name?: undefined;
            color?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                tasks: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    title: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                    priority: import("zod").ZodEnum<{
                        high: "high";
                        medium: "medium";
                        low: "low";
                        none: "none";
                    }>;
                    parent_id: import("zod").ZodOptional<import("zod").ZodString>;
                    type: import("zod").ZodEnum<{
                        epic: "epic";
                        feature: "feature";
                        enhancement: "enhancement";
                        bug: "bug";
                        task: "task";
                    }>;
                    status: import("zod").ZodEnum<{
                        open: "open";
                        in_progress: "in_progress";
                        started: "started";
                        done: "done";
                        completed: "completed";
                        closed: "closed";
                        cancelled: "cancelled";
                    }>;
                    open_date: import("zod").ZodOptional<import("zod").ZodString>;
                    in_progress_date: import("zod").ZodOptional<import("zod").ZodString>;
                    closed_date: import("zod").ZodOptional<import("zod").ZodString>;
                    created_id: import("zod").ZodString;
                    assigned_id: import("zod").ZodOptional<import("zod").ZodString>;
                    closed_id: import("zod").ZodOptional<import("zod").ZodString>;
                    deleted: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    creator: import("zod").ZodOptional<import("zod").ZodLazy<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>>;
                    assignee: import("zod").ZodOptional<import("zod").ZodLazy<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>>;
                    closer: import("zod").ZodOptional<import("zod").ZodLazy<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>>;
                    project: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>;
                    cancelled_date: import("zod").ZodOptional<import("zod").ZodString>;
                    tags: import("zod").ZodOptional<import("zod").ZodLazy<import("zod").ZodArray<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        created_at: import("zod").ZodString;
                        name: import("zod").ZodString;
                        color: import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>>>;
                    comments: import("zod").ZodOptional<import("zod").ZodLazy<import("zod").ZodArray<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        created_at: import("zod").ZodString;
                        updated_at: import("zod").ZodString;
                        task_id: import("zod").ZodString;
                        user_id: import("zod").ZodString;
                        author: import("zod").ZodOptional<import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            name: import("zod").ZodString;
                            type: import("zod").ZodOptional<import("zod").ZodEnum<{
                                human: "human";
                                agent: "agent";
                            }>>;
                        }, import("zod/v4/core").$strip>>;
                        body: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>>>;
                    subtask_count: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
                limit: import("zod").ZodNumber;
                offset: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    title: import("zod").ZodOptional<import("zod").ZodString>;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                    priority: import("zod").ZodOptional<import("zod").ZodEnum<{
                        high: "high";
                        medium: "medium";
                        low: "low";
                        none: "none";
                    }>>;
                    parent_id: import("zod").ZodOptional<import("zod").ZodString>;
                    type: import("zod").ZodOptional<import("zod").ZodEnum<{
                        epic: "epic";
                        feature: "feature";
                        enhancement: "enhancement";
                        bug: "bug";
                        task: "task";
                    }>>;
                    status: import("zod").ZodOptional<import("zod").ZodEnum<{
                        open: "open";
                        in_progress: "in_progress";
                        started: "started";
                        done: "done";
                        completed: "completed";
                        closed: "closed";
                        cancelled: "cancelled";
                    }>>;
                    assigned_id: import("zod").ZodOptional<import("zod").ZodString>;
                    closed_id: import("zod").ZodOptional<import("zod").ZodString>;
                    assignee: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    closer: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    project: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            status: string;
            priority: string;
            title?: undefined;
            type?: undefined;
            created_id?: undefined;
            older_than?: undefined;
            limit?: undefined;
            body?: undefined;
            user_id?: undefined;
            name?: undefined;
            color?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    status: import("zod").ZodOptional<import("zod").ZodEnum<{
                        open: "open";
                        in_progress: "in_progress";
                        started: "started";
                        done: "done";
                        completed: "completed";
                        closed: "closed";
                        cancelled: "cancelled";
                    }>>;
                    type: import("zod").ZodOptional<import("zod").ZodEnum<{
                        epic: "epic";
                        feature: "feature";
                        enhancement: "enhancement";
                        bug: "bug";
                        task: "task";
                    }>>;
                    priority: import("zod").ZodOptional<import("zod").ZodEnum<{
                        high: "high";
                        medium: "medium";
                        low: "low";
                        none: "none";
                    }>>;
                    parent_id: import("zod").ZodOptional<import("zod").ZodString>;
                    created_id: import("zod").ZodOptional<import("zod").ZodString>;
                    older_than: import("zod").ZodOptional<import("zod").ZodString>;
                    limit: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                deleted: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    title: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
                count: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            status: string;
            older_than: string;
            limit: number;
            title?: undefined;
            type?: undefined;
            created_id?: undefined;
            priority?: undefined;
            body?: undefined;
            user_id?: undefined;
            name?: undefined;
            color?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                changelog: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    task_id: import("zod").ZodString;
                    field: import("zod").ZodString;
                    old_value: import("zod").ZodOptional<import("zod").ZodString>;
                    new_value: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
                limit: import("zod").ZodNumber;
                offset: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    body: import("zod").ZodString;
                    user_id: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            body: string;
            user_id: string;
            title?: undefined;
            type?: undefined;
            created_id?: undefined;
            priority?: undefined;
            status?: undefined;
            older_than?: undefined;
            limit?: undefined;
            name?: undefined;
            color?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    body: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            body: string;
            title?: undefined;
            type?: undefined;
            created_id?: undefined;
            priority?: undefined;
            status?: undefined;
            older_than?: undefined;
            limit?: undefined;
            user_id?: undefined;
            name?: undefined;
            color?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                comments: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    task_id: import("zod").ZodString;
                    user_id: import("zod").ZodString;
                    author: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    body: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
                limit: import("zod").ZodNumber;
                offset: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    color: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            color: string;
            title?: undefined;
            type?: undefined;
            created_id?: undefined;
            priority?: undefined;
            status?: undefined;
            older_than?: undefined;
            limit?: undefined;
            body?: undefined;
            user_id?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    filename: import("zod").ZodString;
                    content_type: import("zod").ZodOptional<import("zod").ZodString>;
                    size: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                attachment: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    task_id: import("zod").ZodString;
                    user_id: import("zod").ZodString;
                    author: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    filename: import("zod").ZodString;
                    content_type: import("zod").ZodOptional<import("zod").ZodString>;
                    size: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>;
                presigned_url: import("zod").ZodString;
                expiry_seconds: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            filename: string;
            content_type: string;
            title?: undefined;
            type?: undefined;
            created_id?: undefined;
            priority?: undefined;
            status?: undefined;
            older_than?: undefined;
            limit?: undefined;
            body?: undefined;
            user_id?: undefined;
            name?: undefined;
            color?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                presigned_url: import("zod").ZodString;
                expiry_seconds: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                attachments: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    task_id: import("zod").ZodString;
                    user_id: import("zod").ZodString;
                    author: import("zod").ZodOptional<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        type: import("zod").ZodOptional<import("zod").ZodEnum<{
                            human: "human";
                            agent: "agent";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    filename: import("zod").ZodString;
                    content_type: import("zod").ZodOptional<import("zod").ZodString>;
                    size: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                users: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                    type: import("zod").ZodOptional<import("zod").ZodEnum<{
                        human: "human";
                        agent: "agent";
                    }>>;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    type: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            type: string;
            title?: undefined;
            created_id?: undefined;
            priority?: undefined;
            status?: undefined;
            older_than?: undefined;
            limit?: undefined;
            body?: undefined;
            user_id?: undefined;
            color?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                projects: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            title?: undefined;
            type?: undefined;
            created_id?: undefined;
            priority?: undefined;
            status?: undefined;
            older_than?: undefined;
            limit?: undefined;
            body?: undefined;
            user_id?: undefined;
            color?: undefined;
            filename?: undefined;
            content_type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                activity: import("zod").ZodArray<import("zod").ZodObject<{
                    date: import("zod").ZodString;
                    open: import("zod").ZodNumber;
                    inProgress: import("zod").ZodNumber;
                    done: import("zod").ZodNumber;
                    cancelled: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>>;
                days: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=api-reference.d.ts.map